@@ -4,6 +4,10 @@ from typing import Any
 
 from fastmcp import Client
 from joinly_common.types import (
+    MeetingChatHistory,
+    MeetingChatMessage,
+    MeetingParticipant,
+    MeetingParticipantList,
     ServiceUsage,
     SpeakerRole,
     Transcript,
@@ -12,6 +16,10 @@ from joinly_common.types import (
 )
 
 __all__ = [
+    "MeetingChatHistory",
+    "MeetingChatMessage",
+    "MeetingParticipant",
+    "MeetingParticipantList",
     "ServiceUsage",
     "SpeakerRole",
     "Transcript",
@@ -19,7 +27,7 @@ __all__ = [
     "Usage",
 ]
 
-ToolExecutor = Callable[[str, dict[str, Any]], Awaitable[Any]]
+type ToolExecutor = Callable[[str, dict[str, Any]], Awaitable[Any]]
 
 
 @dataclass
@@ -28,3 +36,4 @@ class McpClientConfig:
 
     client: Client
     exclude: list[str] = field(default_factory=list)
+    include: list[str] = field(default_factory=list)
